//[mahjong-utils](../../../index.md)/[mahjongutils.models.hand](../index.md)/[Hand](index.md)/[patterns](patterns.md)

# patterns

[common]\
val [patterns](patterns.md): [Collection](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-collection/index.html)&lt;[P](index.md)&gt;

手牌形
